import QtQuick 2.0
import QtLocation 5.3
import QtPositioning 5.0
import QtQml 2.0
import QtQuick.Controls 2.0
import QtGraphicalEffects 1.0

ApplicationWindow  {
    id: window
    width: 1024
    height: 768
    visible: true
    title: "Cell find"
    x: 100
    y: 100

    property string mapDir: ""

    function mapf(x, in_min, in_max, out_min, out_max) {
        return (x - in_min) * (out_max - out_min) / (in_max - in_min) + out_min;
    }

    signal qmlCellParam(string mcc, string mnc, string lac, string cellId)

    Connections {
        target: appCore
        onSetCoord: {
            console.log(lat, lon);
            mapId.center = QtPositioning.coordinate(lat, lon)
            mapId.zoomLevel = 13
            mcId.center = QtPositioning.coordinate(lat, lon)
            mapText.text = msg;
        }
    }

    Plugin {
        id: mapPlugin
        name: "osm"

        PluginParameter {
            name: "osm.mapping.host";
            value: "http://a.tile.openstreet.org/"
        }
        PluginParameter {
            name: "osm.mapping.cache.directory"
            value: '/osm_maps/'
        }
        PluginParameter {
            name: "osm.mapping.highdpi_tiles";
            value: true
        }
    }

    Map {
        property bool mapOffline: false

        id: mapId
        /*anchors.left: gbCellParam.right
        anchors.right: parent.right
        anchors.top: parent.top
        anchors.bottom: parent.bottom*/
        anchors.fill: parent
        anchors.bottomMargin: 10
        anchors.topMargin: 10
        anchors.rightMargin: 10
        anchors.leftMargin: 10
        plugin: mapPlugin
        //activeMapType: map.supportedMapTypes[1]
        center: QtPositioning.coordinate(59.122612, 37.903470)  // Череповец
        zoomLevel: 12
        copyrightsVisible: false

        onZoomLevelChanged: {            
            mcId.radius = mapf(mapId.zoomLevel, 0.0, 18.0, 800.0, 20.0)
            console.log(zoomLevel, mcId.radius)
        }

        MapCircle {
            id: mcId
            /*center {
                latitude: 59.122612
                longitude: 37.903470
            }*/
            radius: 20.0
            width: 0
            color: "#80C0F400"
        }

        //property int msgTxtSize: 24
        TextArea {
            id: mapText
            text: qsTr("Please enter parameters and click button [Get cell info]")
            anchors.left: cellParamFields.right
            anchors.right: parent.right
            anchors.top: parent.top
            font.pixelSize: 24

            height: mapText.contentHeight + 24 / 2
            anchors.rightMargin: 10
            anchors.leftMargin: 10
            anchors.topMargin: 10
            wrapMode: TextEdit.WordWrap
            selectByMouse: true

            Rectangle {
                anchors.fill: parent
                radius: 10
                color: "#d0d0ff"
                opacity: 0.5
            }

            ToolTip.delay: 500
            ToolTip.timeout: 5000
            ToolTip.visible: hovered
            ToolTip.text: "Click to hide"

            MouseArea {
                anchors.fill: parent
                onClicked: {
                    if(mapText.height == mapText.contentHeight + 24 / 2) {
                        mapText.height = 10
                        mapText.ToolTip.text = "Click to show"
                    }
                    else {
                        mapText.height =  mapText.contentHeight + 24 / 2
                        mapText.ToolTip.text = "Click to hide"
                    }
                }
            }

            onTextChanged: {
                mapText.height =  mapText.contentHeight + 24 / 2
            }            

            onContentHeightChanged: {
                mapText.height =  mapText.contentHeight + 24 / 2
            }
        }

        Rectangle {
            id: cellParamFields
            //signal cellParam(string mcc, string mnc, string lac, string cellId)
            width: 150
            height: 336

            anchors.top: parent.top
            anchors.leftMargin: 10
            anchors.topMargin: 10
            //anchors.bottomMargin: 10

            radius: 10
            color: "#d0d0ff"
            opacity: 0.9
            anchors.left: parent.left

            /*Component.onCompleted: {
                cellParamFields.height = content
            }*/

            Text {
                id: mccId
                text: qsTr("MCC")
                anchors.left: parent.left
                anchors.right: parent.right
                anchors.top: parent.top
                anchors.rightMargin: 10
                anchors.leftMargin: 10
                anchors.topMargin: 10
            }

            TextField {
                id: tfMCC
                text: qsTr("250")
                anchors.left: parent.left
                anchors.right: parent.right
                anchors.top: mccId.bottom
                anchors.rightMargin: 10
                anchors.leftMargin: 10
                anchors.topMargin: 5
                selectByMouse: true
            }

            Text {
                id: mncId
                text: qsTr("MNC")
                anchors.left: parent.left
                anchors.right: parent.right
                anchors.top: tfMCC.bottom
                anchors.rightMargin: 10
                anchors.leftMargin: 10
                anchors.topMargin: 10
            }

            TextField {
                id: tfMNC
                text: qsTr("2")
                anchors.left: parent.left
                anchors.right: parent.right
                anchors.top: mncId.bottom
                anchors.rightMargin: 10
                anchors.leftMargin: 10
                anchors.topMargin: 5
                selectByMouse: true
            }

            Text {
                id: lacId
                text: qsTr("LAC/TAC")
                anchors.left: parent.left
                anchors.right: parent.right
                anchors.top: tfMNC.bottom
                anchors.rightMargin: 10
                anchors.leftMargin: 10
                anchors.topMargin: 10
            }

            TextField {
                id: tfLAC
                //text: qsTr("3554")
                anchors.left: parent.left
                anchors.right: parent.right
                anchors.top: lacId.bottom
                anchors.rightMargin: 10
                anchors.leftMargin: 10
                anchors.topMargin: 5
                selectByMouse: true
            }

            Text {
                id: cellId
                text: qsTr("Cell ID")
                anchors.left: parent.left
                anchors.right: parent.right
                anchors.top: tfLAC.bottom
                anchors.rightMargin: 10
                anchors.leftMargin: 10
                anchors.topMargin: 10
            }

            TextField {
                id: tfCellID
                //text: qsTr("90193666")
                anchors.left: parent.left
                anchors.right: parent.right
                anchors.top: cellId.bottom
                anchors.rightMargin: 10
                anchors.leftMargin: 10
                anchors.topMargin: 5
                selectByMouse: true
            }

            Button {
                id: getParamBtn
                anchors.left: parent.left
                anchors.right: parent.right
                anchors.top: tfCellID.bottom
                anchors.topMargin: 10
                anchors.rightMargin: 10
                anchors.leftMargin: 10

                onClicked: {
                    //cellParam(tfMCC.text, tfMNC.text, tfLAC.text, tfCellID.text)
                    //console.log(tfMCC.text, tfMNC.text, tfLAC.text, tfCellID.text)
                    qmlCellParam(tfMCC.text, tfMNC.text, tfLAC.text, tfCellID.text)
                }

                Text {
                    text: "Get cell info"
                    anchors.fill: parent
                    horizontalAlignment: Text.AlignHCenter
                    verticalAlignment: Text.AlignVCenter
                }
            }
        }
    }
}
